@@ -33,7 +33,7 @@ from assignbot.s3_utils import download_file, upload_file
 
 TO_REVIEW_LABEL = "To Review"
 REVIEW_ACCESS_LEVEL = 30  # developper
-CLIENT_PROJECT_TAG = "client-project"
+DO_NOT_REVIEW_TAG = "no-assignbot"
 
 STATE_FILENAME = "auto_assigned_reviewers.csv"
 PENDING_MR_MESSAGE = """\
@@ -179,11 +179,12 @@ class ReviewAssigner:
                 continue
 
             project = self.cnx.projects.get(merge_request.project_id)
-            if CLIENT_PROJECT_TAG in project.tag_list:
-                # it's a client project. Let's assume that someone will take
+            if DO_NOT_REVIEW_TAG in project.tag_list:
+                # has the 'no-assignbot' tag. Let's assume that someone will take
                 # care of this MR.
                 print(
-                    f"INFO: {merge_request.web_url} would need review, but it's a client project"
+                    f"INFO: {merge_request.web_url} would need review, but it "
+                    "has the '{DO_NOT_REVIEW_TAG}' tag"
                 )
                 continue
             yield merge_request
